pub enum Loss {
Mse,
Mae,
BinaryCrossEntropyWithLogits,
SoftmaxCrossEntropy,
}Expand description
Supported loss functions.
Variants
Mse
Mean squared error.
Mae
Mean absolute error.
BinaryCrossEntropyWithLogits
Binary cross-entropy with logits.
This expects raw logits as predictions and targets in [0, 1].
In most cases you should use an Identity activation on the output layer.
SoftmaxCrossEntropy
Softmax cross-entropy.
This expects raw logits as predictions and a one-hot target vector.
In most cases you should use an Identity activation on the output layer.
Implementations