Model serialization/deserialization (feature: serde).
This module defines a versioned, stable on-disk format for Mlp.
Design notes:
- We do NOT directly serialize internal
Mlp/Layerstructs, to keep the file format stable even if internal representation changes. - All deserialization validates dimensions, parameter lengths, and that all parameters are finite.