Loss

Enum Loss 

pub enum Loss {
    Mse,
    Mae,
    BinaryCrossEntropyWithLogits,
    SoftmaxCrossEntropy,
}
Supported loss functions.

Variants



Mse

Mean squared error.



Mae

Mean absolute error.



BinaryCrossEntropyWithLogits

Binary cross-entropy with logits.

This expects raw logits as predictions and targets in [0, 1]. In most cases you should use an Identity activation on the output layer.



SoftmaxCrossEntropy

Softmax cross-entropy.

This expects raw logits as predictions and a one-hot target vector. In most cases you should use an Identity activation on the output layer.

Implementations

Source

impl Loss

pub fn validate(self) -> Result<()>

Validate a loss configuration.

pub fn forward(self, pred: &[f32], target: &[f32]) -> f32

Compute a loss value.

Shape contract: pred.len() == target.len().

pub fn backward(self, pred: &[f32], target: &[f32], d_pred: &mut [f32]) -> f32

Compute loss + gradient w.r.t pred.

Writes d_pred = dL/d(pred) into d_pred and returns the loss.

Shape contract:

  • pred.len() == target.len()
  • pred.len() == d_pred.len()